RSS
====

.. autoclass:: qbittorrentapi.rss.RSSAPIMixIn
    :members:
    :undoc-members:
    :exclude-members: rss, rss_addFolder, rss_addFeed, rss_removeItem, rss_moveItem, rss_refreshItem, rss_markAsRead, rss_setRule, rss_renameRule, rss_removeRule, rss_matchingArticles, rss_setFeedURL
    :show-inheritance:

.. autoclass:: qbittorrentapi.rss.RSS
    :members:
    :undoc-members:
    :special-members: __call__
    :exclude-members: rss, addFolder, addFeed, removeItem, moveItem, refreshItem, markAsRead, setRule, renameRule, removeRule, matchingArticles, setFeedURL

.. autoclass:: qbittorrentapi.rss.RSSitemsDictionary
    :members:
    :undoc-members:
    :show-inheritance:

.. autoclass:: qbittorrentapi.rss.RSSRulesDictionary
    :members:
    :undoc-members:
    :show-inheritance:
